Documentation
¶
Index ¶
- func ClientPIDFromContext(ctx context.Context) int
- func ResolveEnvLines(ctx context.Context, app *AppState, lines []string) ([]string, []error)
- func RunDaemon()
- func RunTray(app *AppState)
- type AWSResolver
- type AppState
- type AzureResolver
- type DaemonServer
- type GCPResolver
- type KPResolver
- type KeychainResolver
- type OnePasswordResolver
- type UserResolver
- type VaultResolver
- type WincredResolver
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClientPIDFromContext ¶ added in v1.2.0
ClientPIDFromContext returns the peer PID associated with the current HTTP request, or 0 if unavailable.
func ResolveEnvLines ¶
ResolveEnvLines processes KEY=VALUE lines and replaces values of the form keepass(vault|title) and user(title) with resolved passwords. Bracketed vaults may contain at most one nested expression. When a nested expression is present, its resolved value is passed to the upper-level KP resolver via the context (not by mutating the vault string).
Types ¶
type AWSResolver ¶
type AppState ¶
type AppState struct {
KP KPResolver
USER UserResolver
WINCRED WincredResolver
AWS AWSResolver
AZKV AzureResolver
GCPSM GCPResolver
KEYCHAIN KeychainResolver
VAULT VaultResolver
ONEPASSWORD OnePasswordResolver
UnlockTTL utils.AtomicDuration
ShouldExit utils.AtomicBool
RetrievalApproval utils.AtomicBool
Approvals *approval.Store
Gate *approval.Gate
Audit *audit.Logger
Server *DaemonServer
}
func NewAppState ¶
func NewAppState() *AppState
type AzureResolver ¶ added in v1.1.0
type DaemonServer ¶
type DaemonServer struct {
App *AppState
Endpoint string
// contains filtered or unexported fields
}
func NewDaemonServer ¶
func NewDaemonServer(app *AppState, token string) (*DaemonServer, error)
func (*DaemonServer) Serve ¶
func (ds *DaemonServer) Serve() error
type GCPResolver ¶ added in v1.1.0
type KPResolver ¶
type KPResolver interface {
SetUnlockTTL(unlockTTL *utils.AtomicDuration)
LoadAliases() error
LoadKeyfiles() error
ResolvePassword(ctx context.Context, vault, title string, master string, ttl time.Duration, resolve func(expr string) (string, error)) (string, error)
EvictVault(key string)
EvictAll()
CachedVaults() []keepass.CachedVault
IsVaultUnlocked(key string) bool
Aliases() []keepass.AliasInfo
SetAliases(list []keepass.AliasInfo) error
Keyfiles() []keepass.KeyfileInfo
SetKeyfiles(list []keepass.KeyfileInfo) error
}
type KeychainResolver ¶ added in v1.1.0
type OnePasswordResolver ¶ added in v1.1.0
type UserResolver ¶
type VaultResolver ¶ added in v1.1.0
Click to show internal directories.
Click to hide internal directories.